{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Generate visual and tabular summaries of a feature table",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-sample-metadata-file"
                    },
                    "id": "#feature-table-summarize.cwl/sample_metadata_file"
                },
                {
                    "type": "File",
                    "label": "feature table to be summarized",
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "id": "#feature-table-summarize.cwl/table"
                },
                {
                    "type": "string",
                    "label": "filename for the resulting visualization file",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#feature-table-summarize.cwl/visualization_filename"
                }
            ],
            "baseCommand": [
                "qiime",
                "feature-table",
                "summarize"
            ],
            "id": "#feature-table-summarize.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.visualization_filename)"
                    },
                    "id": "#feature-table-summarize.cwl/visualization"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Generate tabular view of feature identifier to sequence mapping, including links to BLAST each sequence against the NCBI nt database",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "feature sequences to be tabulated",
                    "inputBinding": {
                        "prefix": "--i-data"
                    },
                    "id": "#feature-table-tabulate-seqs.cwl/data"
                },
                {
                    "type": "string",
                    "label": "filename for the resulting visualization file",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#feature-table-tabulate-seqs.cwl/visualization_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.visualization_filename)"
                    },
                    "id": "#feature-table-tabulate-seqs.cwl/visualization"
                }
            ],
            "baseCommand": [
                "qiime",
                "feature-table",
                "tabulate-seqs"
            ],
            "id": "#feature-table-tabulate-seqs.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "label": "qiime2 create feature visual summaries",
            "doc": "FeatureTable and FeatureData summaries from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/feature_table_artifact"
                },
                {
                    "type": "string",
                    "default": "table.qzv",
                    "id": "#main/feature_table_summary_filename"
                },
                {
                    "type": "string",
                    "default": "rep-seqs.qzv",
                    "id": "#main/feature_table_tabulation_filename"
                },
                {
                    "type": "File",
                    "id": "#main/rep_seqs_artifact"
                },
                {
                    "type": "File",
                    "id": "#main/sample_metadata"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/feature_table_summarize/visualization",
                    "id": "#main/feature_table_summarize_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#main/feature_table_tabulation/visualization",
                    "id": "#main/feature_table_tabulation_visualization"
                }
            ],
            "steps": [
                {
                    "run": "#feature-table-summarize.cwl",
                    "in": [
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/feature_table_summarize/sample_metadata_file"
                        },
                        {
                            "source": "#main/feature_table_artifact",
                            "id": "#main/feature_table_summarize/table"
                        },
                        {
                            "source": "#main/feature_table_summary_filename",
                            "id": "#main/feature_table_summarize/visualization_filename"
                        }
                    ],
                    "out": [
                        "#main/feature_table_summarize/visualization"
                    ],
                    "id": "#main/feature_table_summarize"
                },
                {
                    "run": "#feature-table-tabulate-seqs.cwl",
                    "in": [
                        {
                            "source": "#main/rep_seqs_artifact",
                            "id": "#main/feature_table_tabulation/data"
                        },
                        {
                            "source": "#main/feature_table_tabulation_filename",
                            "id": "#main/feature_table_tabulation/visualization_filename"
                        }
                    ],
                    "out": [
                        "#main/feature_table_tabulation/visualization"
                    ],
                    "id": "#main/feature_table_tabulation"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
